pub struct HtmlGenerator<'a> { /* private fields */ }Expand description
HTML page generator.
Implementations
Sourceimpl<'a> HtmlGenerator<'a>
impl<'a> HtmlGenerator<'a>
Sourcepub fn new(config: &'a Config) -> Self
pub fn new(config: &'a Config) -> Self
Create a new HTML generator with the given configuration.
Sourcepub fn with_templates(config: &'a Config, templates: TemplateRegistry) -> Self
pub fn with_templates(config: &'a Config, templates: TemplateRegistry) -> Self
Create a generator with custom templates.
Sourcepub fn with_sections(self, sections: Vec<String>) -> Self
pub fn with_sections(self, sections: Vec<String>) -> Self
Set content sections for dynamic navigation.
Sourcepub fn register_template(&mut self, template: Template)
pub fn register_template(&mut self, template: Template)
Register a custom template.
Sourcepub fn generate_page(
&self,
page: &Page,
alternates: &[(&str, &str)],
) -> Result<String>
pub fn generate_page( &self, page: &Page, alternates: &[(&str, &str)], ) -> Result<String>
Generate HTML for a page.
Sourcepub fn generate_redirect(&self, redirect_url: &str) -> Result<String>
pub fn generate_redirect(&self, redirect_url: &str) -> Result<String>
Generate redirect HTML for URL aliases.
Sourcepub fn generate_list_page(
&self,
title: &str,
items_html: &str,
pagination_html: Option<&str>,
) -> Result<String>
pub fn generate_list_page( &self, title: &str, items_html: &str, pagination_html: Option<&str>, ) -> Result<String>
Generate a list page HTML.
Sourcepub fn generate_taxonomy_page(
&self,
taxonomy_name: &str,
term: &str,
items_html: &str,
pagination_html: Option<&str>,
) -> Result<String>
pub fn generate_taxonomy_page( &self, taxonomy_name: &str, term: &str, items_html: &str, pagination_html: Option<&str>, ) -> Result<String>
Generate a taxonomy term page HTML.
Sourcepub fn output_path(&self, page: &Page, output_dir: &Path) -> PathBuf
pub fn output_path(&self, page: &Page, output_dir: &Path) -> PathBuf
Get the output path for a page.
Generate a tags index page listing all tags with their counts.
Sourcepub fn generate_categories_index_page(
&self,
categories: &HashMap<String, Vec<String>>,
lang: &str,
) -> Result<String>
pub fn generate_categories_index_page( &self, categories: &HashMap<String, Vec<String>>, lang: &str, ) -> Result<String>
Generate a categories index page listing all categories with their counts.
Sourcepub fn generate_archives_page(
&self,
pages: &[&Page],
lang: &str,
) -> Result<String>
pub fn generate_archives_page( &self, pages: &[&Page], lang: &str, ) -> Result<String>
Generate an archives page listing all posts grouped by year.